Module: Google::Cloud::Profiler
- Defined in:
- lib/google/cloud/profiler.rb,
lib/google/cloud/profiler/version.rb
Constant Summary collapse
- VERSION =
"1.7.0"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.profiler| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-profiler library.
-
.export_service(version: :v2, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ExportService.
-
.export_service_available?(version: :v2, transport: :grpc) ⇒ boolean
Determines whether the ExportService service is supported by the current client.
-
.profiler_service(version: :v2, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ProfilerService.
-
.profiler_service_available?(version: :v2, transport: :grpc) ⇒ boolean
Determines whether the ProfilerService service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.profiler| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-profiler library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
222 223 224 225 226 |
# File 'lib/google/cloud/profiler.rb', line 222 def self.configure yield ::Google::Cloud.configure.profiler if block_given? ::Google::Cloud.configure.profiler end |
.export_service(version: :v2, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ExportService.
By default, this returns an instance of
Google::Cloud::Profiler::V2::ExportService::Client
for a gRPC client for version V2 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ExportService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ExportService service. You can determine whether the method will succeed by calling export_service_available?.
About ExportService
Service allows existing Cloud Profiler customers to export their profile data out of Google Cloud.
150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/google/cloud/profiler.rb', line 150 def self.export_service version: :v2, transport: :grpc, &block require "google/cloud/profiler/#{version.to_s.downcase}" package_name = Google::Cloud::Profiler .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Profiler.const_get(package_name).const_get(:ExportService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.export_service_available?(version: :v2, transport: :grpc) ⇒ boolean
Determines whether the ExportService service is supported by the current client. If true, you can retrieve a client object by calling export_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ExportService service, or if the versioned client gem needs an update to support the ExportService service.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/google/cloud/profiler.rb', line 174 def self.export_service_available? version: :v2, transport: :grpc require "google/cloud/profiler/#{version.to_s.downcase}" package_name = Google::Cloud::Profiler .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Profiler.const_get package_name return false unless service_module.const_defined? :ExportService service_module = service_module.const_get :ExportService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.profiler_service(version: :v2, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ProfilerService.
By default, this returns an instance of
Google::Cloud::Profiler::V2::ProfilerService::Client
for a gRPC client for version V2 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ProfilerService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ProfilerService service. You can determine whether the method will succeed by calling profiler_service_available?.
About ProfilerService
Manage the collection of continuous profiling data provided by profiling agents running in the cloud or by an offline provider of profiling data.
The APIs listed in this service are intended for use within our profiler agents only.
79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/google/cloud/profiler.rb', line 79 def self.profiler_service version: :v2, transport: :grpc, &block require "google/cloud/profiler/#{version.to_s.downcase}" package_name = Google::Cloud::Profiler .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Profiler.const_get(package_name).const_get(:ProfilerService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.profiler_service_available?(version: :v2, transport: :grpc) ⇒ boolean
Determines whether the ProfilerService service is supported by the current client. If true, you can retrieve a client object by calling profiler_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ProfilerService service, or if the versioned client gem needs an update to support the ProfilerService service.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/google/cloud/profiler.rb', line 103 def self.profiler_service_available? version: :v2, transport: :grpc require "google/cloud/profiler/#{version.to_s.downcase}" package_name = Google::Cloud::Profiler .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Profiler.const_get package_name return false unless service_module.const_defined? :ProfilerService service_module = service_module.const_get :ProfilerService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |